"use client";

import ConnectionDetailsCard from "@/lib/components/ui/user/ConnectionDetailsCard";
import OwnAliasesCard from "@/lib/components/ui/user/OwnAliasesCard";
import OwnCredentialsCard from "@/lib/components/ui/user/OwnCredentialsCard";
import useWindowDimensions from "@/lib/hooks/useWindowDimensions";
import { Callout, Grid, Heading } from "@radix-ui/themes";
import { CheckIcon } from "lucide-react";
import { useEffect, useState } from "react";

export default function SelfService() {
  const [passwordChanged, setPasswordChanged] = useState(false);
  const dimensions = useWindowDimensions();
  const mobileUi = dimensions.width < 1200;

  function PasswordChangedAlert() {
    const [hide, setHide] = useState(false);

    useEffect(() => {
      let timeout = setTimeout(() => {
        setHide(true);
        setTimeout(() => setPasswordChanged(false), 500);
      }, 5000);
      return () => clearTimeout(timeout);
    });

    return (
      <Callout.Root className={`transition-all ${hide ? "opacity-0 h-0 m-0 !p-0" : " mb-4"}`}>
        <Callout.Icon><CheckIcon /></Callout.Icon>
        <Callout.Text>Password updated!</Callout.Text>
      </Callout.Root>
    );
  }

  return (
    <>
      {passwordChanged && (
        <PasswordChangedAlert />
      )}

      <Heading className="pb-4">Account settings</Heading>

      <Grid display="inline-grid" columns={mobileUi ? "1" : "3"} gap="4" width={mobileUi ? "100%" : "auto"}>
        <OwnCredentialsCard onPasswordChange={() => setPasswordChanged(true)} />
        <ConnectionDetailsCard />
        <OwnAliasesCard />
      </Grid>
    </>
  );
}
